]> git.armaanb.net Git - chorizo.git/blobdiff - config.h
draft 8
[chorizo.git] / config.h
index d782887ca2b0f86bfbf6ab3f0a5d81f9f3bce428..15c30f903b8c07eea83c80ddf3319a8a6d1f5fff 100644 (file)
--- a/config.h
+++ b/config.h
@@ -1,17 +1,27 @@
-#ifndef CONFIG_H
-#define CONFIG_H
-
 #define VERSION "1.1.0"
-gboolean cfg_js_default = TRUE;
-//Should JavaScript be enabled by default
-WebKitCookieAcceptPolicy cfg_cookie_policy = WEBKIT_COOKIE_POLICY_ACCEPT_ALWAYS;
-//Cookie policy
-gchar *cfg_home_uri = NULL;
-//Default URI
-int cfg_scroll_lines = 3;
-//Number of lines to scroll at a time
-gchar *cfg_search_engine = "https://searx.be/search?q=";
-//Search engine
-int cfg_max_tabs_closed = 16;
-
-#endif
+
+// Should JavaScript be enabled by default
+static gboolean cfg_js_default = TRUE;
+
+// Cookie policy
+static WebKitCookieAcceptPolicy cfg_cookie_policy =
+       WEBKIT_COOKIE_POLICY_ACCEPT_ALWAYS;
+
+// Default URI
+static gchar *cfg_home_uri = NULL;
+
+// Number of lines to scroll at a time
+static int cfg_scroll_lines = 3;
+
+// Search engine
+static gchar *cfg_search_engine = "https://searx.be/search?q=";
+
+// Max number of closed tabs
+static size_t cfg_max_tabs_closed = 16;
+
+// Tab width in chars
+static int cfg_tab_width = 15;
+
+// isearch options
+static WebKitFindOptions cfg_isearch_options =
+       WEBKIT_FIND_OPTIONS_CASE_INSENSITIVE | WEBKIT_FIND_OPTIONS_WRAP_AROUND;